@@ -17,8 +17,6 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-from __future__ import with_statement
-
 import os
 import logging
 
@@ -38,35 +36,16 @@ def delete_comment(line):
         return line
 
 
-def get_config(dirs):
-    default_config_file = os.path.join(dirs.files_dir, 'default.cfg')
-    default_config = Config(default_config_file)
-
-    user_config = Config(dirs.config_file)
-
-    config = Config()
-
-    #Add the defaults
-    if default_config:
-        config.update(default_config)
-
-    #Overwrite existing values with user options
-    if user_config:
-        config.update(user_config)
-
-    return config
-
-
 
 class Config(dict):
-
     def __init__(self, config_file):
         dict.__init__(self)
 
         self.file = config_file
 
-        self.obsolete_keys = [u'useGTKMozembed',
-                              u'LD_LIBRARY_PATH', u'MOZILLA_FIVE_HOME']
+        self.obsolete_keys = [u'useGTKMozembed', u'useWebkit',
+                              u'LD_LIBRARY_PATH', u'MOZILLA_FIVE_HOME',
+                              u'cloudTabActive']
 
         # Allow changing the value of portable only in default.cfg
         self.suppressed_keys = ['portable', 'user_dir']
@@ -115,7 +94,7 @@ class Config(dict):
             if '=' in key_value_pair:
                 try:
                     # Delete whitespace around =
-                    pair = key_value_pair.split('=')
+                    pair = key_value_pair.partition('=')[::2]
                     key, value = map(unicode.strip, pair)
 
                     # Do not add obsolete keys -> they will not be rewritten
@@ -181,13 +160,21 @@ class Config(dict):
 
 
     def save_to_disk(self):
-        assert self.changed()
+        if not self.changed():
+            return
 
         content = ''
         for key, value in sorted(self.iteritems()):
             if key not in self.suppressed_keys:
                 content += ('%s=%s\n' % (key, value))
 
-        filesystem.write_file(self.file, content)
-        logging.info('Configuration has been saved to disk')
-        self.old_config = self.copy()
+        try:
+            filesystem.make_directory(os.path.dirname(self.file))
+            filesystem.write_file(self.file, content)
+        except IOError:
+            logging.error('Configuration could not be saved. Please check '
+                          'your permissions')
+            return
+
+        logging.info('Configuration has been saved to %s' % self.file)
+        self.save_state()
