@@ -28,8 +28,9 @@ TEXT_RESULT_LENGTH = 42
 ALPHA = r'[^\W\d_]'
 ALPHA_NUMERIC = r'\w'
 HEX = r'[0-9A-F]{6}'
+HASHTAG_EXCLUDES = r'%(HEX)s|include' % locals()
 HASHTAG_TEXT = r'%(ALPHA_NUMERIC)s*%(ALPHA)s+%(ALPHA_NUMERIC)s*' % locals()
-HASHTAG_PATTERN = r'(^|[^%(ALPHA_NUMERIC)s&]+)(#|\uFF03)(?!%(HEX)s)(%(HASHTAG_TEXT)s)' % locals()
+HASHTAG_PATTERN = r'(^|[^%(ALPHA_NUMERIC)s&]+)(#|\uFF03)(?!%(HASHTAG_EXCLUDES)s)(%(HASHTAG_TEXT)s)' % locals()
 HASHTAG = re.compile(HASHTAG_PATTERN, flags=re.I | re.U)
 
 def escape_tag(tag):
@@ -82,7 +83,7 @@ def get_text_with_dots(text, start, end, found_text=None):
 
 
 class Day(object):
-    def __init__(self, month, day_number, day_content = None):
+    def __init__(self, month, day_number, day_content=None):
         if day_content is None:
             day_content = {'text': u''}
 
@@ -109,7 +110,7 @@ class Day(object):
         if 'text' in self.content:
             return self.content['text'].decode('utf-8')
         else:
-           return ''
+            return ''
 
     def _set_text(self, text):
         self.content['text'] = text
@@ -157,7 +158,7 @@ class Day(object):
     @property
     def hashtags(self):
         # The same tag can occur multiple times.
-        return [hashtag for _, _hash, hashtag in HASHTAG.findall(self.text)]
+        return [hashtag.lower() for _, _hash, hashtag in HASHTAG.findall(self.text)]
 
     @property
     def categories(self):
@@ -247,7 +248,8 @@ class Day(object):
 
         found_text = self.text[occurence:occurence + len(search_text)]
         result_text = get_text_with_dots(self.text, occurence,
-                                    occurence + len(search_text), found_text)
+                                         occurence + len(search_text),
+                                         found_text)
         return result_text
 
 
@@ -275,8 +277,8 @@ class Day(object):
 
 
 class Month(object):
-    def __init__(self, year_number, month_number, month_content = None):
-        if month_content == None:
+    def __init__(self, year_number, month_number, month_content=None):
+        if month_content is None:
             month_content = {}
 
         self.edited = False
@@ -309,11 +311,11 @@ class Month(object):
         return True
 
     def same_month(date1, date2):
-        if date1 == None or date2 == None:
+        if date1 is None or date2 is None:
             return False
         return date1.month == date2.month and date1.year == date2.year
     same_month = staticmethod(same_month)
 
     def __cmp__(self, other):
         return cmp((self.year_number, self.month_number),
-                    (other.year_number, other.month_number))
+                   (other.year_number, other.month_number))
