@@ -29,15 +29,15 @@ import gobject
 if __name__ == '__main__':
     sys.path.insert(0, '../../')
 
-from rednotebook.util import filesystem
 from rednotebook.util import markup
 
 
 try:
     import webkit
-except ImportError:
+except ImportError as err:
     logging.error('Webkit was not found. It can be found in a package '
-                  'with the name python-webkit or pywebkitgtk. ')
+                  'with the name python-webkit or pywebkitgtk.\n'
+                  '%s' % err)
     sys.exit(1)
 
 
@@ -84,13 +84,13 @@ class HtmlPrinter(object):
     "A non-interactive tool for converting any given website to PDF"
     (http://github.com/eeejay/interwibble/)
     """
-    PAPER_SIZES = {'a3'     : gtk.PAPER_NAME_A3,
-                   'a4'     : gtk.PAPER_NAME_A4,
-                   'a5'     : gtk.PAPER_NAME_A5,
-                   'b5'     : gtk.PAPER_NAME_B5,
-                   'executive' : gtk.PAPER_NAME_EXECUTIVE,
-                   'legal'   : gtk.PAPER_NAME_LEGAL,
-                   'letter' : gtk.PAPER_NAME_LETTER}
+    PAPER_SIZES = {'a3': gtk.PAPER_NAME_A3,
+                   'a4': gtk.PAPER_NAME_A4,
+                   'a5': gtk.PAPER_NAME_A5,
+                   'b5': gtk.PAPER_NAME_B5,
+                   'executive': gtk.PAPER_NAME_EXECUTIVE,
+                   'legal': gtk.PAPER_NAME_LEGAL,
+                   'letter': gtk.PAPER_NAME_LETTER}
 
     def __init__(self, paper='a4'):
         self._webview = Browser()
@@ -249,13 +249,12 @@ class HtmlView(gtk.ScrolledWindow):
 if __name__ == '__main__':
     logging.getLogger('').setLevel(logging.DEBUG)
     sys.path.insert(0, os.path.abspath("./../../"))
-    from rednotebook.util import markup
     text = 'PDF export works 1 www.heise.de $\\sum i^2$'
-    html = markup.convert(text, 'xhtml')
+    html = markup.convert(text, 'xhtml', '/tmp')
 
     win = gtk.Window()
     win.connect("destroy", lambda w: gtk.main_quit())
-    win.set_default_size(600,400)
+    win.set_default_size(600, 400)
 
     vbox = gtk.VBox()
 
