@@ -36,7 +36,7 @@ from rednotebook.util import markup
 from rednotebook.util import dates
 from rednotebook.gui import customwidgets
 from rednotebook.gui.customwidgets import Calendar, AssistantPage, \
-                                    RadioButtonPage, PathChooserPage, Assistant
+    RadioButtonPage, PathChooserPage, Assistant
 from rednotebook.gui import browser
 from rednotebook.gui import options
 
@@ -49,15 +49,19 @@ class DatePage(AssistantPage):
         self.journal = journal
 
         self.all_days_button = gtk.RadioButton(label=_('Export all days'))
+        self.selected_text_button = gtk.RadioButton(
+            label=_('Export currently selected text'),
+            group=self.all_days_button)
         self.one_day_button = gtk.RadioButton(
-                                    label=_('Export currently visible day'),
-                                    group=self.all_days_button)
+            label=_('Export currently visible day'),
+            group=self.all_days_button)
         self.sel_days_button = gtk.RadioButton(
-                    label=_('Export days in the selected time range'),
-                    group=self.all_days_button)
+            label=_('Export days in the selected time range'),
+            group=self.all_days_button)
 
         self.pack_start(self.all_days_button, False)
         self.pack_start(self.one_day_button, False)
+        self.pack_start(self.selected_text_button, False)
         self.pack_start(self.sel_days_button, False)
 
         label1 = gtk.Label()
@@ -101,6 +105,10 @@ class DatePage(AssistantPage):
         return self.all_days_button.get_active()
 
 
+    def export_selected_text(self):
+        return self.selected_text_button.get_active()
+
+
     def get_date_range(self):
         if self.select_days:
             return (self.calendar1.get_date(), self.calendar2.get_date())
@@ -127,18 +135,19 @@ class ContentsPage(AssistantPage):
         self.date_format = options.DateFormatOption(_('Date format'), 'exportDateFormat')
         self.date_format.combo.combo_box.set_tooltip_text(_('Leave blank to omit dates in export'))
 
-        self.text_button = gtk.CheckButton(label=_('Include text'))
-        self.all_categories_button = gtk.RadioButton(label=_('Include all tags'))
-        self.no_categories_button = gtk.RadioButton(label=_('Do not include tags'),
-                                            group=self.all_categories_button)
-        self.sel_categories_button = gtk.RadioButton(label=_('Include only the selected tags'),
-                                            group=self.all_categories_button)
+        self.text_and_tags_button = gtk.RadioButton(label=_('Export text and tags'))
+        self.text_only_button = gtk.RadioButton(label=_('Export text only'),
+                                                group=self.text_and_tags_button)
+        self.tags_only_button = gtk.RadioButton(label=_('Export tags only'),
+                                                group=self.text_and_tags_button)
+        self.filter_tags_button = gtk.CheckButton(label=_('Filter days by tags'))
 
         self.pack_start(self.date_format, False)
-        self.pack_start(self.text_button, False)
-        self.pack_start(self.all_categories_button, False)
-        self.pack_start(self.no_categories_button, False)
-        self.pack_start(self.sel_categories_button, False)
+        self.pack_start(self.text_and_tags_button, False)
+        self.pack_start(self.text_only_button, False)
+        self.pack_start(self.tags_only_button, False)
+        self.pack_start(gtk.HSeparator(), False)
+        self.pack_start(self.filter_tags_button, False)
 
         self.available_categories = customwidgets.CustomListView([(_('Available tags'), str)])
         self.selected_categories = customwidgets.CustomListView([(_('Selected tags'), str)])
@@ -173,13 +182,8 @@ class ContentsPage(AssistantPage):
 
         self.pack_end(self.error_text, False, False)
 
-        self.text_button.set_active(True)
-
-        self.text_button.connect('toggled', self.check_selection)
-        self.all_categories_button.connect('toggled', self.check_selection)
-        self.no_categories_button.connect('toggled', self.check_selection)
-        self.sel_categories_button.connect('toggled', self.check_selection)
-
+        self.text_and_tags_button.set_active(True)
+        self.filter_tags_button.connect('toggled', self.check_selection)
 
     def refresh_categories_list(self):
         model_available = gtk.ListStore(gobject.TYPE_STRING)
@@ -190,12 +194,11 @@ class ContentsPage(AssistantPage):
         model_selected = gtk.ListStore(gobject.TYPE_STRING)
         self.selected_categories.set_model(model_selected)
 
-
     def on_select_category(self, widget):
         selection = self.available_categories.get_selection()
         nb_selected, selected_iter = selection.get_selected()
 
-        if selected_iter != None :
+        if selected_iter is not None:
             model_available = self.available_categories.get_model()
             model_selected = self.selected_categories.get_model()
 
@@ -208,12 +211,11 @@ class ContentsPage(AssistantPage):
 
         self.check_selection()
 
-
     def on_deselect_category(self, widget):
         selection = self.selected_categories.get_selection()
         nb_selected, selected_iter = selection.get_selected()
 
-        if selected_iter != None :
+        if selected_iter is not None:
             model_available = self.available_categories.get_model()
             model_selected = self.selected_categories.get_model()
 
@@ -226,20 +228,21 @@ class ContentsPage(AssistantPage):
 
         self.check_selection()
 
-
     def set_error_text(self, text):
         self.error_text.set_markup('<b>' + text + '</b>')
 
-
     def is_text_included(self):
-        return self.text_button.get_active()
+        return self.text_only_button.get_active() or self.text_and_tags_button.get_active()
 
+    def is_tags_included(self):
+        return self.tags_only_button.get_active() or self.text_and_tags_button.get_active()
+
+    def is_filtered(self):
+        return self.filter_tags_button.get_active()
 
     def get_categories(self):
-        if self.all_categories_button.get_active():
+        if not self.filter_tags_button.get_active():
             return self.journal.categories
-        elif self.no_categories_button.get_active():
-            return []
         else:
             selected_categories = []
             model_selected = self.selected_categories.get_model()
@@ -249,17 +252,16 @@ class ContentsPage(AssistantPage):
 
             return selected_categories
 
-
     def check_selection(self, *args):
-        if not self.is_text_included() and not self.get_categories():
-            error = _('If include text is not selected, you have to select at least one tag.')
+        if self.is_filtered() and not self.get_categories():
+            error = _('When filtering by tags, you have to select at least one tag.')
             self.set_error_text(error)
             correct = False
         else:
             self.set_error_text('')
             correct = True
 
-        select = self.sel_categories_button.get_active()
+        select = self.filter_tags_button.get_active()
         self.available_categories.set_sensitive(select)
         self.selected_categories.set_sensitive(select)
         self.select_button.set_sensitive(select)
@@ -342,14 +344,20 @@ class ExportAssistant(Assistant):
 
         self.exporter = None
         self.path = None
+        self.set_forward_page_func(self.pageforward)
 
+    def pageforward(self, page):
+        if page == 2 and self.page2.export_selected_text():
+            return 4
+        else:
+            return page + 1
 
-    def run(self):
+    def run(self, selected_text):
+        self.selected_text = selected_text
         self.page2.refresh_dates()
         self.page3.refresh_categories_list()
         self.show_all()
 
-
     def _on_close(self, assistant):
         '''
         Do the export
@@ -357,7 +365,6 @@ class ExportAssistant(Assistant):
         self.hide()
         self.export()
 
-
     def _on_prepare(self, assistant, page):
         '''
         Called when a new page should be prepared, before it is shown
@@ -367,7 +374,12 @@ class ExportAssistant(Assistant):
             self.exporter = self.page1.get_selected_object()
         elif page == self.page3:
             # Categories
-            pass
+            start_date, end_date = self.page2.get_date_range()
+            if not self.page2.export_all_days() and start_date == end_date:
+                self.page3.filter_tags_button.set_active(False)
+                self.page3.filter_tags_button.set_sensitive(False)
+            else:
+                self.page3.filter_tags_button.set_sensitive(True)
         elif page == self.page4:
             # Path
             self.page4.prepare(self.exporter)
@@ -376,50 +388,69 @@ class ExportAssistant(Assistant):
             self.path = self.page4.get_selected_path()
             self.page5.prepare()
             self.export_all_days = self.page2.export_all_days()
-            self.is_text_included = self.page3.is_text_included()
+            self.export_selected_text = self.page2.export_selected_text()
+            self.is_filtered = self.page3.is_filtered()
             self.exported_categories = self.page3.get_categories()
 
             self.page5.add_setting(_('Format'), self.exporter.NAME)
             self.page5.add_setting(_('Export all days'), self.yes_no(self.export_all_days))
             if not self.export_all_days:
                 start_date, end_date = self.page2.get_date_range()
-                self.page5.add_setting(_('Start date'), start_date)
-                self.page5.add_setting(_('End date'), end_date)
-            is_text_included = self.yes_no(self.is_text_included)
-            self.page5.add_setting(_('Include text'), is_text_included)
-            self.page5.add_setting(_('Selected tags'), ', '.join(self.exported_categories))
+                if start_date == end_date:
+                    self.page5.add_setting(_('Date'), start_date)
+                    self.page5.add_setting(_('Export selected text only'), self.yes_no(self.export_selected_text))
+                else:
+                    self.page5.add_setting(_('Start date'), start_date)
+                    self.page5.add_setting(_('End date'), end_date)
+            if self.export_selected_text:
+                self.exported_categories = []
+            else:
+                self.page5.add_setting(_('Include text'), self.yes_no(self.page3.is_text_included()))
+                self.page5.add_setting(_('Include tags'), self.yes_no(self.page3.is_tags_included()))
+            if self.is_filtered:
+                self.page5.add_setting(_('Filtered by tags'), ', '.join(self.exported_categories))
             self.page5.add_setting(_('Export path'), self.path)
 
-
     def yes_no(self, value):
         return _('Yes') if value else _('No')
 
-
     def get_export_string(self, format):
-        if self.export_all_days:
-            export_days = self.journal.days
+        if self.export_selected_text and self.selected_text:
+            markup_string = self.selected_text
         else:
-            export_days = self.journal.get_days_in_date_range(*self.page2.get_date_range())
+            if self.export_all_days:
+                export_days = self.journal.days
+            else:
+                export_days = self.journal.get_days_in_date_range(*self.page2.get_date_range())
 
-        selected_categories = self.exported_categories
-        logging.debug('Selected Categories for Inclusion: %s' % selected_categories)
-        include_text = self.is_text_included
+            selected_categories = self.exported_categories
+            logging.debug('Selected Categories for Inclusion: %s' % selected_categories)
 
-        # Save selected date format
-        date_format = self.page3.date_format.get_value()
-        self.journal.config['exportDateFormat'] = date_format
+            # Save selected date format
+            date_format = self.page3.date_format.get_value()
+            self.journal.config['exportDateFormat'] = date_format
 
-        markup_strings_for_each_day = []
-        for day in export_days:
-            date_string = dates.format_date(date_format, day.date)
-            day_markup = markup.get_markup_for_day(day, with_text=include_text,
-                                            categories=selected_categories,
-                                            date=date_string)
-            markup_strings_for_each_day.append(day_markup)
+            markup_strings_for_each_day = []
+            for day in export_days:
+                include_day = True
+                if self.is_filtered:
+                    include_day = False
+                    catagory_pairs = day.get_category_content_pairs()
+                    for category in selected_categories:
+                        if category in catagory_pairs:
+                            include_day = True
+                if include_day:
+                    date_string = dates.format_date(date_format, day.date)
+                    day_markup = markup.get_markup_for_day(day, with_text=self.page3.is_text_included(),
+                                                           with_tags=self.page3.is_tags_included(),
+                                                           categories=selected_categories,
+                                                           date=date_string)
+                    markup_strings_for_each_day.append(day_markup)
 
-        markup_string = ''.join(markup_strings_for_each_day)
+            markup_string = ''.join(markup_strings_for_each_day)
 
-        return markup.convert(markup_string, format, options={'toc': 0})
+        return markup.convert(markup_string, format, self.journal.dirs.data_dir,
+                              options={'toc': 0})
 
     def export(self):
         format = self.exporter.FORMAT
@@ -482,18 +513,12 @@ class Exporter(object):
 
     @property
     def DEFAULTPATH(self):
-        return os.path.join(os.path.expanduser('~'), 'RedNotebook-Export_%s.%s' %
-                                (datetime.date.today(), self.EXTENSION))
-
-
-
-
-
-
+        return os.path.join(os.path.expanduser('~'),
+            'RedNotebook-Export_%s.%s' % (datetime.date.today(), self.EXTENSION))
 
 
 class PlainTextExporter(Exporter):
-    NAME = 'Plain Text'
+    NAME = _('Plain Text')
     #DESCRIPTION = 'Export journal to a plain textfile'
     EXTENSION = 'txt'
     FORMAT = 'txt'
@@ -524,7 +549,7 @@ class PdfExporter(Exporter):
         if self.is_available():
             return ''
         else:
-            return '(' + _('requires pywebkitgtk') +')'
+            return '(' + _('requires pywebkitgtk') + ')'
 
     @classmethod
     def is_available(cls):
@@ -536,8 +561,6 @@ class PdfExporter(Exporter):
 def get_exporters():
     exporters = [PlainTextExporter, HtmlExporter, LatexExporter, PdfExporter]
 
-    #exporters = filter(lambda exporter: exporter.is_available(), exporters)
-
     # Instantiate importers
     exporters = map(lambda exporter: exporter(), exporters)
     return exporters
@@ -552,4 +575,3 @@ if __name__ == '__main__':
     assistant.set_position(gtk.WIN_POS_CENTER)
     assistant.run()
     gtk.main()
-
