@@ -41,8 +41,8 @@ from rednotebook.data import Day, Month
 from rednotebook.util import filesystem
 from rednotebook import storage
 from rednotebook.util import markup
-from rednotebook.gui.customwidgets import AssistantPage, \
-                    IntroductionPage, RadioButtonPage, PathChooserPage, Assistant
+from rednotebook.gui.customwidgets import AssistantPage, RadioButtonPage, \
+    PathChooserPage, Assistant
 
 class ImportDay(Day):
     '''
@@ -68,9 +68,10 @@ class SummaryPage(AssistantPage):
 
 
     def prepare(self, type, path):
-        parts = [   _('Import type:') + ' <b>' + type + '</b>\n',
-                    _('Path:') + ' <b>' + path + '</b>\n\n',
-                    _('The following contents will be imported:')]
+        parts = [
+            _('Import type:') + ' <b>' + type + '</b>\n',
+            _('Path:') + ' <b>' + path + '</b>\n\n',
+            _('The following contents will be imported:')]
         self.set_header(''.join(parts))
         self.clear()
 
@@ -194,8 +195,8 @@ class Importer(object):
             try:
                 __import__(module)
             except ImportError, err:
-                logging.info('"%s" could not be imported. '
-                    'You will not be able to import %s' % (module, cls.NAME))
+                logging.info('"%s" could not be imported: %s\nYou will not be '
+                             'able to import %s' % (module, err, cls.NAME))
                 # Importer cannot be used
                 return False
         return True
@@ -242,13 +243,8 @@ class PlainTextImporter(Importer):
     PATHTYPE = 'DIR'
 
     # Allow 2010-05-08[.txt] with different or no separators
-    sep = r'[:\._\-]?' # The separators :._-
+    sep = r'[:\._\-]?'  # The separators :._-
     date_exp = re.compile(r'(\d{4})%s(\d{2})%s(\d{2})(?:\.txt)?' % (sep, sep))
-    ref_date = datetime.date(2010, 5, 8)
-    for test in ['2010-05-08', '2010.05-08', '2010:05_08.TxT', '20100508.TXT']:
-        match = date_exp.match(test)
-        date = datetime.date(int(match.group(1)), int(match.group(2)), int(match.group(3)))
-        assert date == ref_date
 
     def get_days(self, dir):
         for file in self._get_files(dir):
@@ -272,9 +268,6 @@ class RedNotebookImporter(Importer):
     PATHTEXT = _('Select a directory containing RedNotebook data files')
     PATHTYPE = 'DIR'
 
-    def __init__(self):
-        date_exp = re.compile(r'(\d{4})-(\d{2})\.txt')
-
     def get_days(self, dir):
         assert os.path.isdir(dir)
         months = storage.load_all_months_from_disk(dir)
@@ -290,9 +283,6 @@ class RedNotebookBackupImporter(RedNotebookImporter):
     PATHTYPE = 'FILE'
     EXTENSION = 'zip'
 
-    def __init__(self):
-        date_exp = re.compile(r'(\d{4})-(\d{2})\.txt')
-
     @classmethod
     def is_available(cls):
         import zipfile
@@ -336,10 +326,6 @@ class TomboyImporter(Importer):
                             'Library', 'Application Support', 'Tomboy')
     PATHTYPE = 'DIR'
 
-    @classmethod
-    def is_available(cls):
-        return cls._check_modules(['xml.etree'])
-
     def get_days(self, dir):
         '''
         We do not check if there are multiple notes for one day
@@ -377,11 +363,8 @@ def get_importers():
     importers = [cls for name, cls in globals().items()
                 if name.endswith('Importer') and not name == 'Importer']
 
-    importers = filter(lambda importer: importer.is_available(), importers)
-
-    # Instantiate importers
-    importers = map(lambda importer: importer(), importers)
-    return importers
+    # Filter and instantiate importers.
+    return [imp() for imp in importers if imp.is_available()]
 
 
 
@@ -395,7 +378,7 @@ if __name__ == '__main__':
     assistant.run()
     gtk.main()
 
-    a = ImportDay(2010,5,7)
+    a = ImportDay(2010, 5, 7)
     a.text = 'a_text'
     a.add_category_entry('c1', 'e1')
     a.add_category_entry('c2', 'e2')
@@ -403,7 +386,7 @@ if __name__ == '__main__':
 
     print a.content
 
-    b = ImportDay(2010,5,7)
+    b = ImportDay(2010, 5, 7)
     b.text = 'b_text'
     b.add_category_entry('c1', 'e1')
     b.add_category_entry('c2', 'e3')
@@ -416,8 +399,8 @@ if __name__ == '__main__':
     assert a_tree == a.content
 
     assert a.text == 'a_text\n\nb_text'
-    assert a.tree == {'c1': {'e1': None}, 'c2': {'e2': None, 'e3':None},
-            'c4': {'e5': None}, 'c3': {'e4': None},}, a.tree
+    assert a.tree == {'c1': {'e1': None}, 'c2': {'e2': None, 'e3': None},
+            'c4': {'e5': None}, 'c3': {'e4': None}}, a.tree
 
     print 'ALL TESTS SUCCEEDED'
 
@@ -426,12 +409,3 @@ if __name__ == '__main__':
 #print dir(plaintext_module)
 #p = getattr(plaintext_module, 'aha')
 #p = plaintext_module.PlainTextImporter()
-
-
-
-
-
-
-
-
-
