@@ -21,7 +21,6 @@ import sys
 import os
 import datetime
 import logging
-import urlparse
 
 import gtk
 import gobject
@@ -42,10 +41,8 @@ from rednotebook.gui import browser
 from rednotebook.gui import search
 from rednotebook.gui.editor import Editor
 from rednotebook.gui.clouds import Cloud
-
-test_zeitgeist = False
-if test_zeitgeist:
-    from rednotebook.gui import journalgeist
+from rednotebook.gui import insert_menu
+from rednotebook.gui import format_menu
 
 
 class MainWindow(object):
@@ -66,22 +63,30 @@ class MainWindow(object):
         except gobject.GError, err:
             logging.error('An error occured while loading the GUI: %s' % err)
             logging.error('RedNotebook requires at least gtk+ 2.14. '
-                            'If you cannot update gtk, you might want to try an '
-                            'older version of RedNotebook.')
+                          'If you cannot update gtk, you might want to try an '
+                          'older version of RedNotebook.')
             sys.exit(1)
 
 
         # Get the main window and set the icon
         self.main_frame = self.builder.get_object('main_frame')
         self.main_frame.set_title('RedNotebook')
-        icon = gtk.gdk.pixbuf_new_from_file(os.path.join(filesystem.frame_icon_dir,
-                                                         'rednotebook.svg'))
+        try:
+            icon = gtk.gdk.pixbuf_new_from_file(os.path.join(filesystem.frame_icon_dir,
+                                                             'rednotebook.svg'))
+        except gobject.GError:
+            icon = gtk.gdk.pixbuf_new_from_file(os.path.join(filesystem.frame_icon_dir,
+                                                             'rn-192.png'))
         self.main_frame.set_icon(icon)
 
         self.is_fullscreen = False
 
         self.uimanager = gtk.UIManager()
 
+        # Before fetching the menubar, add all menus and actiongroups.
+        # Setup the toolbar items first to avoid warnings for missing actions.
+        insert_menu.InsertMenu(self)
+        format_menu.FormatMenu(self)
         self.menubar_manager = MainMenuBar(self)
         self.menubar = self.menubar_manager.get_menu_bar()
         main_vbox = self.builder.get_object('vbox3')
@@ -90,12 +95,18 @@ class MainWindow(object):
 
         self.undo_redo_manager = undo.UndoRedoManager(self)
 
-
         self.calendar = Calendar(self.journal, self.builder.get_object('calendar'))
         self.day_text_field = DayEditor(self.builder.get_object('day_text_view'),
                                         self.undo_redo_manager)
         self.day_text_field.day_text_view.grab_focus()
-        spell_check_enabled = self.journal.config.read('spellcheck', 0)
+        can_spell_check = self.day_text_field.can_spell_check()
+        spell_check_enabled = bool(self.journal.config.read('spellcheck', 0))
+        for actiongroup in self.menubar_manager.uimanager.get_action_groups():
+            if actiongroup.get_name() == 'MainMenuActionGroup':
+                for action in actiongroup.list_actions():
+                    if action.get_name() == 'CheckSpelling':
+                        action.set_sensitive(can_spell_check)
+                        action.set_active(spell_check_enabled and can_spell_check)
         self.day_text_field.enable_spell_check(spell_check_enabled)
 
         self.statusbar = Statusbar(self.builder.get_object('statusbar'))
@@ -103,7 +114,7 @@ class MainWindow(object):
         self.new_entry_dialog = NewEntryDialog(self)
 
         self.categories_tree_view = categories.CategoriesTreeView(
-                        self.builder.get_object('categories_tree_view'), self)
+            self.builder.get_object('categories_tree_view'), self)
 
         self.new_entry_dialog.categories_tree_view = self.categories_tree_view
 
@@ -113,7 +124,7 @@ class MainWindow(object):
 
         self.edit_pane = self.builder.get_object('edit_pane')
 
-        self.html_editor = Preview()
+        self.html_editor = Preview(self.journal)
         self.html_editor.webview.connect('button-press-event', self.on_browser_clicked)
         self.html_editor.webview.connect('navigation-requested', self.on_browser_navigate)
 
@@ -134,6 +145,12 @@ class MainWindow(object):
         else:
             self.infobar = self.statusbar
 
+        # Add TemplateBar.
+        self.template_bar = customwidgets.TemplateBar()
+        self.text_vbox.pack_start(self.template_bar, False, False)
+        self.text_vbox.reorder_child(self.template_bar, 1)
+        self.template_bar.hide()
+
         self.load_values_from_config()
 
         if not self.journal.start_minimized:
@@ -145,8 +162,6 @@ class MainWindow(object):
 
         self.setup_clouds()
         self.setup_search()
-        self.setup_insert_menu()
-        self.setup_format_menu()
 
         # Create an event->method dictionary and connect it to the widgets
         dic = {
@@ -162,15 +177,11 @@ class MainWindow(object):
 
             'on_add_new_entry_button_clicked': self.on_add_new_entry_button_clicked,
 
-            'on_template_button_clicked': self.on_template_button_clicked,
-            'on_template_menu_show_menu': self.on_template_menu_show_menu,
-            'on_template_menu_clicked': self.on_template_menu_clicked,
-
             'on_main_frame_delete_event': self.on_main_frame_delete_event,
 
             # connect_signals can only be called once, it seems
             # Otherwise RuntimeWarnings are raised: RuntimeWarning: missing handler '...'
-             }
+        }
         self.builder.connect_signals(dic)
 
         self.set_shortcuts()
@@ -181,28 +192,8 @@ class MainWindow(object):
         self.setup_template_menu()
 
         self.set_tooltips()
-
-        # Only add the config variable if zeitgeist is available
-        use_zeitgeist = (test_zeitgeist and journalgeist.zeitgeist and
-                        self.journal.config.read('useZeitgeist', 0))
-        self.zeitgeist_widget = None
-        #use_zeitgeist = True
-        logging.info('Using zeitgeist: %s' % use_zeitgeist)
-
-        if use_zeitgeist:
-            self.setup_zeitgeist_view()
-
         self.setup_tray_icon()
 
-
-    def setup_zeitgeist_view(self):
-        '''Zeigeist integration'''
-        #from rednotebook.gui.journalgeist import JournalZeitgeistWidget
-        self.zeitgeist_widget = journalgeist.ZeitgeistWidget()
-        annotations_pane = self.builder.get_object('annotations_pane')
-        annotations_pane.add2(self.zeitgeist_widget)
-
-
     def set_tooltips(self):
         '''
         Little work-around:
@@ -223,7 +214,7 @@ class MainWindow(object):
         '''
         This method actually is not responsible for the Ctrl-C etc. actions
         '''
-        self.accel_group = self.builder.get_object('accelgroup1')#gtk.AccelGroup()
+        self.accel_group = self.builder.get_object('accelgroup1')  # gtk.AccelGroup()
         #self.accel_group = gtk.AccelGroup()
         self.main_frame.add_accel_group(self.accel_group)
         #self.main_frame.add_accel_group()
@@ -232,18 +223,19 @@ class MainWindow(object):
         #   self.day_text_field.day_text_view.add_accelerator(signal, self.accel_group,
         #                   ord(key), gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
-        shortcuts = [(self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
-                    (self.today_button, 'clicked', '<Ctrl>Home'),
-                    (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Down'),
-                    #(self.builder.get_object('undo_menuitem'), 'activate', '<Ctrl>z'),
-                    #(self.builder.get_object('redo_menuitem'), 'activate', '<Ctrl>y'),
-                    #(self.builder.get_object('options_menuitem'), 'activate', '<Ctrl><Alt>p'),
-                    ]
+        shortcuts = [
+            (self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
+            (self.today_button, 'clicked', '<Alt>Home'),
+            (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Down'),
+            #(self.builder.get_object('undo_menuitem'), 'activate', '<Ctrl>z'),
+            #(self.builder.get_object('redo_menuitem'), 'activate', '<Ctrl>y'),
+            #(self.builder.get_object('options_menuitem'), 'activate', '<Ctrl><Alt>p'),
+        ]
 
         for button, signal, shortcut in shortcuts:
             (keyval, mod) = gtk.accelerator_parse(shortcut)
             button.add_accelerator(signal, self.accel_group,
-                                keyval, mod, gtk.ACCEL_VISIBLE)
+                                   keyval, mod, gtk.ACCEL_VISIBLE)
 
 
     # TRAY-ICON / CLOSE --------------------------------------------------------
@@ -262,15 +254,11 @@ class MainWindow(object):
         self.tray_icon.connect('activate', self.on_tray_icon_activated)
         self.tray_icon.connect('popup-menu', self.on_tray_popup_menu)
 
-        self.position = None
-
     def on_tray_icon_activated(self, tray_icon):
         if self.main_frame.get_property('visible'):
             self.hide()
         else:
-            self.main_frame.show()
-            if self.position:
-                self.main_frame.move(*self.position)
+            self.show()
 
     def on_tray_popup_menu(self, status_icon, button, activate_time):
         '''
@@ -291,9 +279,9 @@ class MainWindow(object):
         # Create actions
         actiongroup.add_actions([
             ('Show', gtk.STOCK_MEDIA_PLAY, _('Show RedNotebook'),
-                None, None, lambda widget: self.main_frame.show()),
+                None, None, lambda widget: self.show()),
             ('Quit', gtk.STOCK_QUIT, None, None, None, self.on_quit_activate),
-            ])
+        ])
 
         # Add the actiongroup to the uimanager
         self.uimanager.insert_action_group(actiongroup, 0)
@@ -307,17 +295,20 @@ class MainWindow(object):
         menu.popup(None, None, gtk.status_icon_position_menu,
                 button, activate_time, status_icon)
 
+    def show(self):
+        self.main_frame.show()
+        self.load_values_from_config()
+
     def hide(self):
-        self.position = self.main_frame.get_position()
+        self.add_values_to_config()
+        self.journal.save_to_disk()
         self.main_frame.hide()
-        self.journal.save_to_disk(exit_imminent=False)
 
     def on_main_frame_delete_event(self, widget, event):
         '''
         Exit if not close_to_tray
         '''
         logging.debug('Main frame destroyed')
-        #self.save_to_disk(exit_imminent=False)
 
         if self.journal.config.read('closeToTray', 0):
             self.hide()
@@ -332,7 +323,6 @@ class MainWindow(object):
         '''
         User selected quit from the menu -> exit unconditionally
         '''
-        #self.on_main_frame_destroy(None)
         self.journal.exit()
 
     # -------------------------------------------------------- TRAY-ICON / CLOSE
@@ -358,8 +348,6 @@ class MainWindow(object):
 
     def change_mode(self, preview):
         edit_scroll = self.builder.get_object('text_scrolledwindow')
-        template_button = self.builder.get_object('template_menu_button')
-
         edit_button = self.builder.get_object('edit_button')
         preview_button = self.builder.get_object('preview_button')
 
@@ -383,11 +371,12 @@ class MainWindow(object):
             preview_button.show()
             edit_button.hide()
 
-        template_button.set_sensitive(not preview)
+        self.template_manager.set_template_menu_sensitive(not preview)
         # Disable insert shortcuts in preview mode.
         self.insert_actiongroup.set_sensitive(not preview)
-        self.single_menu_toolbutton.set_sensitive(not preview)
-        self.format_toolbutton.set_sensitive(not preview)
+        self.format_actiongroup.set_sensitive(not preview)
+        self.insert_button.set_sensitive(not preview)
+        self.format_button.set_sensitive(not preview)
 
         self.preview_mode = preview
 
@@ -419,8 +408,8 @@ class MainWindow(object):
         scroll = gtk.ScrolledWindow()
         scroll.add(self.search_tree_view)
         self.builder.get_object('search_container').pack_start(scroll)
-        self.search_box = search.SearchComboBox(self.builder.get_object(
-                                                        'search_box'), self)
+        self.search_box = search.SearchComboBox(
+            self.builder.get_object('search_box'), self)
 
     def setup_clouds(self):
         self.cloud = Cloud(self.journal)
@@ -482,16 +471,6 @@ class MainWindow(object):
 
         uri = request.get_uri()
         logging.info('Clicked URI "%s"' % uri)
-        path = urlparse.urlparse(uri).path
-
-        # Check if relative file exists and convert if it does.
-        if not uri.startswith('http'):
-            assert path.startswith('/'), path
-            relpath = os.path.join(self.journal.dirs.data_dir, path[1:])
-            assert os.path.isabs(relpath), relpath
-            if os.path.exists(relpath):
-                uri = 'file://%s' % relpath
-
         filesystem.open_url(uri)
 
         # Stop processing that event
@@ -508,11 +487,14 @@ class MainWindow(object):
 
         response = dir_chooser.run()
         # Retrieve the dir now, because it will be cleared by the call to hide().
-        new_dir = dir_chooser.get_filename().decode('utf-8')
+        new_dir = dir_chooser.get_filename()
         dir_chooser.hide()
 
         if response == gtk.RESPONSE_OK:
-            return new_dir
+            if new_dir is None:
+                self.journal.show_message(_('No directory selected.'), error=True)
+                return None
+            return new_dir.decode('utf-8')
         return None
 
 
@@ -560,7 +542,7 @@ class MainWindow(object):
     def load_values_from_config(self):
         config = self.journal.config
         main_frame_width = config.read('mainFrameWidth', 1024)
-        main_frame_height = config.read('mainFrameHeight', 768)
+        main_frame_height = config.read('mainFrameHeight', 700)
 
         screen_width = gtk.gdk.screen_width()
         screen_height = gtk.gdk.screen_height()
@@ -605,373 +587,26 @@ class MainWindow(object):
         self.day_text_field.set_font_size(main_font_size)
         self.html_editor.set_font_size(main_font_size)
 
-
     def setup_template_menu(self):
-        self.template_menu_button = self.builder.get_object('template_menu_button')
-        self.template_menu_button.set_menu(gtk.Menu())
-        self.template_menu_button.set_menu(self.template_manager.get_menu())
-
-
-    def on_template_menu_show_menu(self, widget):
-        self.template_menu_button.set_menu(self.template_manager.get_menu())
-
-    def on_template_menu_clicked(self, widget):
-        text = self.template_manager.get_weekday_text()
-        #self.day_text_field.insert_template(text)
-        self.day_text_field.insert(text)
-
-    def on_template_button_clicked(self, widget):
-        text = self.template_manager.get_weekday_text()
-        self.day_text_field.insert(text)
-
-
-    def setup_format_menu(self):
-        '''
-        See http://www.pygtk.org/pygtk2tutorial/sec-UIManager.html for help
-        A popup menu cannot show accelerators (HIG).
-        '''
-
-        format_menu_xml = '''
-        <ui>
-        <popup action="FormatMenu">
-            <menuitem action="Bold"/>
-            <menuitem action="Italic"/>
-            <menuitem action="Underline"/>
-            <menuitem action="Strikethrough"/>
-        </popup>
-        </ui>'''
-
-        uimanager = self.uimanager
-
-        # Create an ActionGroup
-        actiongroup = gtk.ActionGroup('FormatActionGroup')
-
-        def tmpl(word):
-            return word + ' (Ctrl+%s)' % word[0]
-
-        def apply_format(action, format='bold'):
-            format_to_markup = {'bold': '**', 'italic': '//', 'underline': '__',
-                                'strikethrough': '--'}
-            if type(action) == gtk.Action:
-                format = action.get_name().lower()
-
-            markup = format_to_markup[format]
-
-            focus = self.main_frame.get_focus()
-            iter = self.categories_tree_view.get_selected_node()
-
-            if isinstance(focus, gtk.Entry):
-                entry = focus
-                pos = entry.get_position()
-                # bounds can be an empty tuple
-                bounds = entry.get_selection_bounds() or (pos, pos)
-                selected_text = entry.get_chars(*bounds).decode('utf-8')
-                entry.delete_text(*bounds)
-                entry.insert_text('%s%s%s' % (markup, selected_text, markup), bounds[0])
-                # Set cursor after the end of the formatted text
-                entry.set_position(bounds[0] + len(markup) + len(selected_text))
-            elif focus == self.categories_tree_view.tree_view and iter:
-                text = self.categories_tree_view.get_iter_value(iter)
-                text = '%s%s%s' % (markup, text, markup)
-                self.categories_tree_view.set_iter_value(iter, text)
-            elif focus == self.day_text_field.day_text_view:
-                self.day_text_field.apply_format(format, markup)
-            else:
-                self.journal.show_message(_('No text or tag has been selected.'),
-                                          error=True)
-
-        def shortcut(char):
-            ### Translators: The Control (Ctrl) key
-            return ' (%s+%s)' % (_('Ctrl'), char)
-
-        # Create actions
-        actions = [ ('Bold', gtk.STOCK_BOLD, _('Bold') + shortcut('B'), '<Control>B', None, apply_format),
-                    ('Italic', gtk.STOCK_ITALIC, _('Italic') + shortcut('I'), '<Control>I', None, apply_format),
-                    ('Underline', gtk.STOCK_UNDERLINE, _('Underline') + shortcut('U'), '<Control>U', None, apply_format),
-                    ('Strikethrough', gtk.STOCK_STRIKETHROUGH, _('Strikethrough'), None, None, apply_format)]
-
-        actiongroup.add_actions(actions)
-
-        # Add the actiongroup to the uimanager
-        uimanager.insert_action_group(actiongroup, 0)
-
-        # Add a UI description
-        uimanager.add_ui_from_string(format_menu_xml)
-
-        # Create a Menu
-        menu = uimanager.get_widget('/FormatMenu')
-
-        #single_menu_toolbutton = SingleMenuToolButton(menu, 'Insert ')
-        self.format_toolbutton = gtk.MenuToolButton(gtk.STOCK_BOLD)
-        ### Translators: noun
-        self.format_toolbutton.set_label(_('Format'))
-        tip = _('Format the selected text or tag')
-        self.format_toolbutton.set_tooltip_text(tip)
-        self.format_toolbutton.set_menu(menu)
-        bold_func = apply_format#lambda widget: self.day_text_field.apply_format('bold')
-        self.format_toolbutton.connect('clicked', bold_func)
-        edit_toolbar = self.builder.get_object('edit_toolbar')
-        edit_toolbar.insert(self.format_toolbutton, -1)
-        self.format_toolbutton.show()
-
-
-    def setup_insert_menu(self):
-        '''
-        See http://www.pygtk.org/pygtk2tutorial/sec-UIManager.html for help
-        A popup menu cannot show accelerators (HIG).
-        '''
-
-        insert_menu_xml = '''
-        <ui>
-        <popup action="InsertMenu">
-            <menuitem action="Picture"/>
-            <menuitem action="File"/>
-            <menuitem action="Link"/>
-            <menuitem action="BulletList"/>
-            %(numlist_ui)s
-            <menuitem action="Title"/>
-            <menuitem action="Line"/>
-            %(table_ui)s
-            %(formula_ui)s
-            <menuitem action="Date"/>
-            <menuitem action="LineBreak"/>
-        </popup>
-        </ui>'''
-
-        numlist_ui = '' #'<menuitem action="NumberedList"/>'
-        table_ui = '' # '<menuitem action="Table"/>'
-        formula_ui = '' #'<menuitem action="Formula"/>'
-
-        insert_menu_xml = insert_menu_xml % locals()
-
-        uimanager = self.uimanager
-
-        # Add the accelerator group to the toplevel window
-        accelgroup = uimanager.get_accel_group()
-        self.main_frame.add_accel_group(accelgroup)
-
-        # Create an ActionGroup
-        self.insert_actiongroup = gtk.ActionGroup('InsertActionGroup')
-
-        line = '\n====================\n'
-
-        item1 = _('First Item')
-        item2 = _('Second Item')
-        item3 = _('Indented Item')
-        close = _('Two blank lines close the list')
-        bullet_list = '\n- %s\n- %s\n  - %s (%s)\n\n\n' % (item1, item2, item3, close)
-        numbered_list = bullet_list.replace('-', '+')
-
-        title_text = _('Title text')
-        title = '\n=== %s ===\n' % title_text
-
-        table = ('\n|| Whitespace Left | Whitespace Right | Resulting Alignment |\n'
-                   '| 1               | more than 1     | Align left   |\n'
-                   '|     more than 1 |               1 |   Align right |\n'
-                   '|   more than 1   |   more than 1   |   Center   |\n'
-                   '|| Title rows | are always | centered |\n'
-                   '|  Use two vertical  |  lines on the left  |  for title rows  |\n'
-                   '|  Always use  |  at least  |  one whitespace  |\n')
-
-        formula = '\\(\\sum_{i=1}^n i = \\frac{n(n+1)}{2}\\)'
-
-        line_break = r'\\'
-
-        def insert_date_time(widget):
-            format_string = self.journal.config.read('dateTimeString', '%A, %x %X')
-            date_string = dates.format_date(format_string)
-            self.day_text_field.insert(date_string)
-
-        def tmpl(letter):
-            return ' (Ctrl+%s)' % letter
-
-        # Create actions
-        self.insert_actiongroup.add_actions([
-            ('Picture', gtk.STOCK_ORIENTATION_PORTRAIT,
-                _('Picture'),
-                None, _('Insert an image from the harddisk'),
-                self.on_insert_pic_menu_item_activate),
-            ('File', gtk.STOCK_FILE, _('File'), None,
-                _('Insert a link to a file'),
-                self.on_insert_file_menu_item_activate),
-            ### Translators: Noun
-            ('Link', gtk.STOCK_JUMP_TO, _('_Link') + tmpl('L'), '<Control>L',
-                _('Insert a link to a website'),
-                self.on_insert_link_menu_item_activate),
-            ('BulletList', None, _('Bullet List'), None, None,
-                lambda widget: self.day_text_field.insert(bullet_list)),
-            ('NumberedList', None, _('Numbered List'), None, None,
-                lambda widget: self.day_text_field.insert(numbered_list)),
-            ('Title', None, _('Title'), None, None,
-                lambda widget: self.day_text_field.insert(title)),
-            ('Line', None, _('Line'), None,
-                _('Insert a separator line'),
-                lambda widget: self.day_text_field.insert(line)),
-            ('Table', None, _('Table'), None, None,
-                lambda widget: self.day_text_field.insert(table)),
-            ('Formula', None, _('Latex Formula'), None, None,
-                lambda widget: self.day_text_field.insert(formula)),
-            ('Date', None, _('Date/Time') + tmpl('D'), '<Ctrl>D',
-                _('Insert the current date and time (edit format in preferences)'),
-                insert_date_time),
-            ('LineBreak', None, _('Line Break'), None,
-                _('Insert a manual line break'),
-                lambda widget: self.day_text_field.insert(line_break)),
-            ])
-
-        # Add the actiongroup to the uimanager
-        uimanager.insert_action_group(self.insert_actiongroup, 0)
-
-        # Add a UI description
-        uimanager.add_ui_from_string(insert_menu_xml)
-
-        # Create a Menu
-        menu = uimanager.get_widget('/InsertMenu')
-
-        image_items = 'Picture Link BulletList Title Line Date LineBreak Table'.split()
-
-        for item in image_items:
-            menu_item = uimanager.get_widget('/InsertMenu/'+ item)
-            filename = item.lower()
-            # We may have disabled menu items
-            if menu_item:
-                menu_item.set_image(get_image(filename + '.png'))
-
-        self.single_menu_toolbutton = gtk.MenuToolButton(gtk.STOCK_ADD)
-        self.single_menu_toolbutton.set_label(_('Insert'))
-
-        self.single_menu_toolbutton.set_menu(menu)
-        self.single_menu_toolbutton.connect('clicked', self.show_insert_menu)
-        self.single_menu_toolbutton.set_tooltip_text(_('Insert images, files, links and other content'))
-        edit_toolbar = self.builder.get_object('edit_toolbar')
-        edit_toolbar.insert(self.single_menu_toolbutton, -1)
-        self.single_menu_toolbutton.show()
-
-    def show_insert_menu(self, button):
-        '''
-        Show the insert menu, when the Insert Button is clicked.
-
-        A little hack for button and activate_time is needed as the "clicked" does
-        not have an associated event parameter. Otherwise we would use event.button
-        and event.time
-        '''
-        self.single_menu_toolbutton.get_menu().popup(parent_menu_shell=None,
-                            parent_menu_item=None, func=None, button=0, activate_time=0, data=None)
-
-    def on_insert_pic_menu_item_activate(self, widget):
-        dirs = self.journal.dirs
-        picture_chooser = self.builder.get_object('picture_chooser')
-        picture_chooser.set_current_folder(dirs.last_pic_dir)
-
-        filter = gtk.FileFilter()
-        filter.set_name("Images")
-        filter.add_mime_type("image/png")
-        filter.add_mime_type("image/jpeg")
-        filter.add_mime_type("image/gif")
-        filter.add_pattern("*.png")
-        filter.add_pattern("*.jpg")
-        filter.add_pattern("*.jpeg")
-        filter.add_pattern("*.gif")
-        filter.add_pattern("*.bmp")
-
-        picture_chooser.add_filter(filter)
-
-        # Add box for inserting image width.
-        box = gtk.HBox()
-        box.set_spacing(2)
-        label = gtk.Label(_('Width (optional):'))
-        width_entry = gtk.Entry(max=6)
-        width_entry.set_width_chars(6)
-        box.pack_start(label, False)
-        box.pack_start(width_entry, False)
-        box.pack_start(gtk.Label(_('pixels')), False)
-        box.show_all()
-        picture_chooser.set_extra_widget(box)
-
-        response = picture_chooser.run()
-        picture_chooser.hide()
-
-        if response == gtk.RESPONSE_OK:
-            dirs.last_pic_dir = picture_chooser.get_current_folder().decode('utf-8')
-            base, ext = os.path.splitext(picture_chooser.get_filename().decode('utf-8'))
-
-            # On windows firefox accepts absolute filenames only
-            # with the file:/// prefix
-            base = filesystem.get_local_url(base)
-
-            width_text = ''
-            width = width_entry.get_text().decode('utf-8')
-            if width:
-                try:
-                    width = int(width)
-                except ValueError:
-                    self.journal.show_message(_('Width must be an integer.'), error=True)
-                    return
-                width_text = '?%d' % width
-
-            self.day_text_field.insert('[""%s""%s%s]' % (base, ext, width_text))
-
-    def on_insert_file_menu_item_activate(self, widget):
-        dirs = self.journal.dirs
-        file_chooser = self.builder.get_object('file_chooser')
-        file_chooser.set_current_folder(dirs.last_file_dir)
-
-        response = file_chooser.run()
-        file_chooser.hide()
-
-        if response == gtk.RESPONSE_OK:
-            dirs.last_file_dir = file_chooser.get_current_folder().decode('utf-8')
-            filename = file_chooser.get_filename().decode('utf-8')
-            filename = filesystem.get_local_url(filename)
-            head, tail = os.path.split(filename)
-            # It is always safer to add the "file://" protocol and the ""s
-            self.day_text_field.insert('[%s ""%s""]' % (tail, filename))
-
-    def on_insert_link_menu_item_activate(self, widget):
-        link_creator = self.builder.get_object('link_creator')
-        link_location_entry = self.builder.get_object('link_location_entry')
-        link_name_entry = self.builder.get_object('link_name_entry')
-
-        link_location_entry.set_text('http://')
-        link_name_entry.set_text('')
-
-        def link_entered():
-            return bool(link_location_entry.get_text())
-
-        def on_link_changed(widget):
-            # Only make the link submittable, if text has been entered.
-            link_creator.set_response_sensitive(gtk.RESPONSE_OK, link_entered())
-
-        link_location_entry.connect('changed', on_link_changed)
-
-        # Let user finish by hitting ENTER.
-        def respond(widget):
-            if link_entered():
-                link_creator.response(gtk.RESPONSE_OK)
-
-        link_location_entry.connect('activate', respond)
-        link_name_entry.connect('activate', respond)
-
-        link_location_entry.grab_focus()
-
-        response = link_creator.run()
-        link_creator.hide()
-
-        if response == gtk.RESPONSE_OK:
-            link_location = link_location_entry.get_text()
-            link_name = link_name_entry.get_text()
-
-            if link_location and link_name:
-                self.day_text_field.insert('[%s ""%s""]' % (link_name, link_location))
-            elif link_location:
-                self.day_text_field.insert(link_location)
-            else:
-                self.journal.show_message(_('No link location has been entered'), error=True)
+        def update_menu(button):
+            self.template_button.set_menu(self.template_manager.get_menu())
+
+        self.template_button = customwidgets.ToolbarMenuButton(gtk.STOCK_PASTE,
+                                        self.template_manager.get_menu())
+        self.template_button.set_label(_('Template'))
+        self.template_button.connect('show-menu', update_menu)
+        self.template_button.set_tooltip_text(_("Insert this weekday's template. "
+                        "Click the arrow on the right for more options"))
+        self.builder.get_object('edit_toolbar').insert(self.template_button, 2)
 
     def on_add_new_entry_button_clicked(self, widget):
         self.categories_tree_view._on_add_entry_clicked(None)
 
     def set_date(self, new_month, new_date, day):
+        """
+        Notes: When switching days in edit mode almost all processing
+        time is used for highlighting the markup (searching regexes).
+        """
         self.day = day
         self.categories_tree_view.clear()
 
@@ -994,11 +629,7 @@ class MainWindow(object):
             self.html_editor.show_day(day)
 
         self.categories_tree_view.set_day_content(day)
-
-        if self.zeitgeist_widget:
-            self.zeitgeist_widget.set_date(new_date)
-
-        self.undo_redo_manager.set_date(new_date)
+        self.undo_redo_manager.set_stack(new_date)
 
     def get_day_text(self):
         return self.day_text_field.get_text()
@@ -1015,8 +646,9 @@ class MainWindow(object):
 
 
 class Preview(browser.HtmlView):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, journal, *args, **kwargs):
         browser.HtmlView.__init__(self, *args, **kwargs)
+        self.journal = journal
         self.day = None
 
     def show_day(self, new_day):
@@ -1027,7 +659,7 @@ class Preview(browser.HtmlView):
 
         # Show new day
         self.day = new_day
-        html = markup.convert(self.day.text, 'xhtml')
+        html = markup.convert(self.day.text, 'xhtml', self.journal.dirs.data_dir)
         self.load_html(html)
 
         if self.day.last_preview_pos is not None:
@@ -1216,7 +848,7 @@ class Calendar(object):
         self.calendar.select_day(1)
 
         # PyGTK calendars show months in range [0,11]
-        self.calendar.select_month(date.month-1, date.year)
+        self.calendar.select_month(date.month - 1, date.year)
 
         # Select the day after the month and year have been set
         self.calendar.select_day(date.day)
@@ -1226,7 +858,7 @@ class Calendar(object):
 
     def get_date(self):
         year, month, day = self.calendar.get_date()
-        return datetime.date(year, month+1, day)
+        return datetime.date(year, month + 1, day)
 
     def set_day_edited(self, day_number, edited):
         '''
@@ -1265,10 +897,3 @@ class Calendar(object):
                         (day_number, cal_month, cal_year))
             return False
         return True
-
-
-def get_image(name):
-    image = gtk.Image()
-    file_name = os.path.join(filesystem.image_dir, name)
-    image.set_from_file(file_name)
-    return image
