@@ -295,19 +295,9 @@ class OptionsManager(object):
             self.options.append(TickOption(_('Close to system tray'), 'closeToTray',
                 tooltip=_('Closing the window will send RedNotebook to the tray')))
 
-        able_to_spell_check = self.main_window.day_text_field.can_spell_check()
-        tooltip = (_('Underline misspelled words') if able_to_spell_check else
-                _('Requires gtkspell.') + ' ' +
-                _('This is included in the python-gtkspell or python-gnome2-extras package'))
-        spell_check_option = TickOption(_('Check Spelling'), 'spellcheck',
-                tooltip=tooltip)
-        if not sys.platform == 'win32':
-            self.options.append(spell_check_option)
-        spell_check_option.set_sensitive(able_to_spell_check)
-
         # Automatic switching between preview and edit mode.
         self.options.append(TickOption(_('Switch between edit and preview mode automatically'),
-                                       'autoSwitchMode', default_value=1))
+                                       'autoSwitchMode', default_value=0))
 
         # Check for new version
         check_version_option = TickOption(_('Check for new version at startup'), 'checkForNewVersion')
@@ -323,13 +313,13 @@ class OptionsManager(object):
         self.options.append(check_version_option)
 
         self.options.extend([
-                FontSizeOption(_('Font Size'), 'mainFontSize'),
-                DateFormatOption(_('Date/Time format'), 'dateTimeString'),
-                CsvTextOption(_('Exclude from cloud'), 'cloudIgnoreList',
-                                tooltip=_('Do not show these comma separated words in the word cloud')),
-                CsvTextOption(_('Include small words in cloud'), 'cloudIncludeList',
-                                tooltip=_('Allow these words with 4 letters or less')),
-                ])
+            FontSizeOption(_('Font Size'), 'mainFontSize'),
+            DateFormatOption(_('Date/Time format'), 'dateTimeString'),
+            CsvTextOption(_('Exclude from cloud'), 'cloudIgnoreList',
+                          tooltip=_('Do not show these comma separated words in the word cloud')),
+            CsvTextOption(_('Include small words in cloud'), 'cloudIncludeList',
+                          tooltip=_('Allow these words with 4 letters or less')),
+        ])
 
 
         self.add_all_options()
@@ -343,9 +333,6 @@ class OptionsManager(object):
             self.main_window.cloud.update_lists()
             self.main_window.cloud.update(force_update=True)
 
-            spell_check_enabled = self.config.read('spellcheck', 0)
-            self.main_window.day_text_field.enable_spell_check(spell_check_enabled)
-
             visible = (self.config.read('closeToTray', 0) == 1)
             self.main_window.tray_icon.set_visible(visible)
         else:
@@ -368,4 +355,3 @@ class OptionsManager(object):
             else:
                 # We don't save the autostart setting in the config file
                 option.set()
-
