@@ -23,25 +23,35 @@ if not hasattr(__builtin__, '_'):
     def _(string):
         return string
 
-version =           '1.6.3'
-author =            'Jendrik Seipp'
-authorMail =        'jendrikseipp@web.de'
-url =               'http://rednotebook.sourceforge.net'
-answers_url =       'https://answers.launchpad.net/rednotebook'
-translation_url =   'https://translations.launchpad.net/rednotebook/'
-bug_url =           'https://bugs.launchpad.net/rednotebook/+filebug'
+try:
+    import argparse
+    assert argparse  # silence pyflakes
+except ImportError:
+    from rednotebook.external import argparse
 
-developers =    ['Jendrik Seipp <jendrikseipp@web.de>']
+
+version = '1.7.1'
+author = 'Jendrik Seipp'
+authorMail = 'jendrikseipp@web.de'
+url = 'http://rednotebook.sourceforge.net'
+answers_url = 'https://answers.launchpad.net/rednotebook'
+translation_url = 'https://translations.launchpad.net/rednotebook/'
+bug_url = 'https://bugs.launchpad.net/rednotebook/+filebug'
+
+developers = ['Jendrik Seipp <jendrikseipp@web.de>',
+              '',
+              'Contributors:',
+              'Alistair Marshall <thatscottishengineer@gmail.com>']
 
 comments = '''\
 RedNotebook is a graphical journal to keep track of notes and
-thoughts. It includes a calendar navigation, customizable
+thoughts. It includes calendar navigation, customizable
 templates, export functionality and word clouds. You can also
 format, tag and search your entries.
 '''
 
 license_text = '''\
-Copyright (c) 2009-2012  Jendrik Seipp
+Copyright (c) 2009-2013  Jendrik Seipp
 
 RedNotebook is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -58,17 +68,29 @@ with RedNotebook; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 '''
 
-command_line_help = '''\
-RedNotebook %s
-
-The optional journal-path can be one of the following:
+journal_path_help = '''\
+(optional) Specify the directory storing the journal data.
+The journal argument can be one of the following:
  - An absolute path (e.g. /home/username/myjournal)
  - A relative path (e.g. ../dir/myjournal)
  - The name of a directory under $HOME/.rednotebook/ (e.g. myjournal)
 
-If the journal-path is omitted the last session's journal will be used.
-At the first program start this defaults to "$HOME/.rednotebook/data".
-''' % version
+If the journal argument is omitted then the last session's journal
+path will be used. At the first program start, this defaults to
+"$HOME/.rednotebook/data".
+'''
+
+def get_commandline_parser():
+    parser = argparse.ArgumentParser(
+        description=comments,
+        formatter_class=argparse.RawTextHelpFormatter)
+    parser.add_argument('--version', action='version',
+                        version='RedNotebook %s' % version)
+    parser.add_argument('-m', '--minimized', dest='minimized', action='store_true',
+                        help='start mimimized to system tray')
+    parser.add_argument('journal', nargs='?', help=journal_path_help)
+    return parser
+
 
 tags = _('Tags')
 work = _('Work')
@@ -79,15 +101,14 @@ rtm = _('Remember the milk')
 dishes = _('Wash the dishes')
 
 greeting = _('Hello!')
-intro=_('Some example text has been added to help you start and '
-'you can erase it whenever you like.')
+intro = _('Some example text has been added to help you start and '
+          'you can erase it whenever you like.')
 ### Translators: "Help" -> noun
 help_par = _('The example text and more documentation is available under "Help" -> "Contents".')
 
 ### Translators: noun
 preview = _('Preview')
 preview1 = _('There are two modes in RedNotebook, the __edit__ mode and the __preview__ mode.')
-### Translators: Edit -> noun
 preview2 = _('Click on Edit above to see the difference.')
 preview_par = ' '.join([preview1, preview2])
 
@@ -166,6 +187,8 @@ multiple_entries_day = {'text': multiple_entries_text + multiple_entries_example
 
 example_content = [welcome_day, multiple_entries_day]
 
+commandline_help = get_commandline_parser().format_help()
+
 help_text = '''
 == Layout ==
 %(preview1)s
@@ -218,7 +241,8 @@ above the main text field. The text will be inserted at the current
 cursor position.
 
 With the insert button you cannot insert **links to directories** on your computer.
-Those can be inserted manually however (``""[Home ""file:///home/""]""``).
+Those can be inserted manually however (``[Home ""file:///home/""]``
+becomes [Home ""file:///home/""]).
 
 == %(templates)s ==
 %(temp_par)s
@@ -244,14 +268,24 @@ You can **hide the word cloud** by adding the regular expression .* to the
 blacklist. This will filter out all words.
 
 == Spellcheck ==
-RedNotebook supports spellchecking your entries if you have
-python-gtkspell installed (Only available on Linux).
-To highlight all misspelled words in your entries, select the corresponding option in
-the preferences window.
+RedNotebook supports spellchecking your entries. On Linux this feature
+needs the package python-gtkspell. The feature can turned on and off by
+toggling the item under the "Edit" menu.
 
 Since gtkspell 2.0.15, you can select the spellchecking language by right-clicking on the
 main text area (in edit mode) and choosing it from the submenu "Languages".
 
+=== Adding custom dictionaries under Windows ===
+We use the dictionaries available from the
+[​openoffice extension download site http://extensions.services.openoffice.org/dictionaries].
+You need to download the appropriate language extension file(s)
+(files are openoffice extensions *.oxt, which are just zip files that
+contain additional data). Once you have downloaded a dictionary extension
+file, you can rename it so it has a .zip extension and then extract the
+*.dic and *.aff files in it to <RedNotebook Dir>\\share\\enchant\\myspell\\.
+If RedNotebook is running, it will need to be restarted for new dictionaries
+to be recognized.
+
 == Options ==
 Make sure you check out the customizable options in the Preferences dialog. You can
 open this dialog by clicking on the entry in the "Edit" menu.
@@ -332,6 +366,14 @@ portable mode.
 To **activate portable mode**, change into the files/ directory and in the
 default.cfg file set portable=1.
 
+== Network drive ==
+Unfortunately, you cannot add links to files on network shares directly
+with the file selection dialog
+([Bug on launchpad ""https://bugs.launchpad.net/ubuntu/+source/gtk+2.0/+bug/304345""]).
+However, it is possible to enter links directly, for example
+``[U: ""file:///U:/""]`` to reference the mapped drive letter
+[U ""file:///U:/""].
+
 == Convert Latex output to PDF ==
 
 In recent RedNotebook versions you can export your journal directly to PDF,
@@ -377,7 +419,7 @@ same directory.
 | Find               | <Ctrl> + F             |
 | Go back one day    | <Ctrl> + PageUp        |
 | Go forward one day | <Ctrl> + PageDown      |
-| Go to today        | <Ctrl> + Home (Pos1)   |
+| Go to today        | <Alt> + Home (Pos1)    |
 | Insert link        | <Ctrl> + L             |
 | Insert date/time   | <Ctrl> + D             |
 | New tag            | <Ctrl> + N             |
@@ -521,25 +563,7 @@ resulting list chronologically by pressing the "Date" button.
 
 == Command line options ==
 ```
-Usage: rednotebook [options] [journal-path]
-
-RedNotebook %(version)s
-
-The optional journal-path can be one of the following:
- - An absolute path (e.g. /home/username/myjournal)
- - A relative path (e.g. ../dir/myjournal)
- - The name of a directory under $HOME/.rednotebook/ (e.g. myjournal)
-
-If the journal-path is omitted the last session's journal will be used.
-At the first program start this defaults to "$HOME/.rednotebook/data".
-
-
-Options:
-  -h, --help        show this help message and exit
-
-  -d, --debug       Output debugging messages (default: False)
-
-  -m, --minimized   Start mimimized to system tray (default: False)
+%(commandline_help)s
 ```
 
 == Data Format ==
