@@ -24,12 +24,11 @@ import time
 import itertools
 import logging
 import locale
-from optparse import OptionParser
 from collections import defaultdict
 
 
 # Use basic stdout logging before we can initialize logging correctly
-logging.basicConfig(level=logging.INFO,
+logging.basicConfig(level=logging.DEBUG,
                     format='%(levelname)-8s %(message)s',
                     stream=sys.stdout)
 
@@ -37,6 +36,7 @@ logging.basicConfig(level=logging.INFO,
 # Allow importing from rednotebook package
 if hasattr(sys, "frozen"):
     from rednotebook.util import filesystem
+    assert filesystem  # silence pyflakes
 else:
     from util import filesystem
 
@@ -64,7 +64,7 @@ try:
     elibintl.install(GETTEXT_DOMAIN, LOCALE_PATH)
 except locale.Error, err:
     # unsupported locale setting
-    logging.error('Locale could not be set: "%s"' %  err)
+    logging.error('Locale could not be set: "%s"' % err)
     logging.error('Probably you have to install the appropriate language packs')
     # Make the _() function available even if gettext is not working.
     import __builtin__
@@ -80,41 +80,23 @@ from rednotebook import configuration
 from rednotebook import data
 
 
-def parse_options():
-    parser = OptionParser(usage="usage: %prog [options] [journal-path]",
-                          description=info.command_line_help,
-                          version="RedNotebook %s" % info.version,
-                          formatter=utils.IndentedHelpFormatterWithNL(),
-                          )
-
-    parser.add_option('-d', '--debug', dest='debug', default=False,
-                      action='store_true', help='Output debugging messages'
-                      ' (default: False)')
-
-    parser.add_option('-m', '--minimized', dest='minimized', default=False,
-                      action='store_true', help='Start mimimized to system tray'
-                      ' (default: False)')
-
-    options, args = parser.parse_args()
-
-    return options, args
-
-options, args = parse_options()
-
-
+args = info.get_commandline_parser().parse_args()
 
 ## ---------------------- Enable logging -------------------------------
 
 def setup_logging(log_file):
     file_logging_stream = open(log_file, 'w')
 
-    # We want to have the error messages in the logfile. In the frozen
-    # version we cannot log to sys.stderr because it's broken on
-    # windows. Stdout is redirected into a blackhole by py2exe.
+    # We want to have all stdout and stderr messages in the logfile.
+    # In the frozen version we cannot log to sys.stderr because it's
+    # broken on windows. Stdout doesn't work either it seems.
     stderr_streams = [file_logging_stream]
-    if not hasattr(sys, 'frozen'):
+    stdout_streams = [file_logging_stream]
+    if not filesystem.main_is_frozen():
         stderr_streams.append(sys.__stderr__)
+        stdout_streams.append(sys.__stdout__)
     sys.stderr = utils.StreamDuplicator(stderr_streams)
+    sys.stdout = utils.StreamDuplicator(stdout_streams)
 
     root_logger = logging.getLogger('')
     root_logger.setLevel(logging.DEBUG)
@@ -124,30 +106,17 @@ def setup_logging(log_file):
     for handler in root_logger.handlers:
         root_logger.removeHandler(handler)
 
-    # define a Handler which writes DEBUG messages or higher to the logfile
-    filelog = logging.StreamHandler(file_logging_stream)
-    filelog.setLevel(logging.DEBUG)
-    filelog_formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(message)s')
-    # tell the handler to use this format
-    filelog.setFormatter(filelog_formatter)
-    # add the handler to the root logger
-    root_logger.addHandler(filelog)
-
-    level = logging.INFO
-    if options.debug:
-        level = logging.DEBUG
-
-    # define a Handler which writes INFO messages or higher to sys.stdout
+    # define a Handler which writes messages to sys.stdout
     console = logging.StreamHandler(sys.stdout)
-    console.setLevel(level)
+    console.setLevel(logging.DEBUG)
     # set a format which is simpler for console use
-    formatter = logging.Formatter('%(levelname)-8s %(message)s')
+    formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(message)s')
     # tell the handler to use this format
     console.setFormatter(formatter)
     # add the handler to the root logger
     root_logger.addHandler(console)
 
-    logging.debug('sys.stdout logging level: %s' % level)
+    logging.debug('Debug message')
     logging.info('Writing log to file "%s"' % log_file)
 
 
@@ -159,6 +128,8 @@ setup_logging(dirs.log_file)
 
 ## ------------------ end Enable logging -------------------------------
 
+logging.info('System encoding: %s' % filesystem.ENCODING)
+logging.info('Language code: %s' % filesystem.LANGUAGE)
 
 try:
     import pygtk
@@ -175,8 +146,8 @@ try:
     # only gtk.gdk.threads_init(): pdf export works, but gui hangs afterwards
     # only gobject.threads_init(): pdf export works, gui works
     # both: pdf export works, gui hangs afterwards
-    gobject.threads_init() # only initializes threading in the glib/gobject module
-    #gtk.gdk.threads_init() # also initializes the gdk threads
+    gobject.threads_init()  # only initializes threading in the glib/gobject module
+    #gtk.gdk.threads_init()  # also initializes the gdk threads
 except (ImportError, AssertionError), e:
     logging.error(e)
     logging.error('gtk not found. Please install PyGTK (python-gtk2)')
@@ -207,14 +178,9 @@ class Journal:
 
         logging.info('Running in portable mode: %s' % self.dirs.portable)
 
-        self.testing = False
-        if options.debug:
-            self.testing = True
-            logging.debug('Debug Mode is on')
-
         # Allow starting minimized to tray
         # When we start minimized we have to set the tray icon visible
-        self.start_minimized = options.minimized
+        self.start_minimized = args.minimized
         if self.start_minimized:
             self.config['closeToTray'] = 1
 
@@ -258,8 +224,7 @@ class Journal:
             utils.check_new_version(self, info.version, startup=True)
 
         # Automatically save the content after a period of time
-        if not self.testing:
-            gobject.timeout_add_seconds(600, self.save_to_disk)
+        gobject.timeout_add_seconds(600, self.save_to_disk)
 
 
     def get_journal_path(self):
@@ -267,7 +232,7 @@ class Journal:
         Retrieve the path from optional args or return standard value if args
         not present
         '''
-        if not args:
+        if not args.journal:
             data_dir = self.config.read('dataDir', self.dirs.data_dir)
             if not os.path.isabs(data_dir):
                 data_dir = os.path.join(self.dirs.app_dir, data_dir)
@@ -278,7 +243,7 @@ class Journal:
         # or an absolute path /home/username/myjournal
         # Try to find the journal under the standard location or at the given
         # absolute or relative location
-        path_arg = args[0]
+        path_arg = args.journal
 
         logging.debug('Trying to find journal "%s"' % path_arg)
 
@@ -290,10 +255,10 @@ class Journal:
                     return path
                 else:
                     logging.warning('To open a journal you must specify a '
-                                'directory, not a file.')
+                                    'directory, not a file.')
 
-        logging.error('The path "%s" is no valid journal directory. '
-                    'Execute "rednotebook -h" for instructions' % path_arg)
+        logging.error('The path "%s" is not a valid journal directory. '
+                      'Execute "rednotebook -h" for instructions' % path_arg)
         sys.exit(1)
 
 
@@ -486,8 +451,7 @@ class Journal:
     @property
     def categories(self):
         return list(sorted(set(itertools.chain.from_iterable(
-                                        day.categories for day in self.days)),
-                           cmp=locale.strcoll))
+            day.categories for day in self.days)), cmp=locale.strcoll))
 
 
     def normalize_tag(self, tag):
@@ -524,6 +488,8 @@ class Journal:
         '''
         Returns a dictionary mapping the words to their number of appearance
         '''
+        # TODO: Use collections.Counter in Python2.7
+        # TODO: Check if concatenating all text and using a regex is faster.
         word_dict = defaultdict(int)
         for day in self.days:
             words = day.get_words()
@@ -607,4 +573,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-
