@@ -17,11 +17,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-import os
-import sys
-import logging
-import re
 import codecs
+import logging
+import os
+import re
+import stat
+import sys
+
 
 try:
     import yaml
@@ -33,6 +35,7 @@ except ImportError:
 try:
     from yaml import CLoader as Loader
     from yaml import CSafeDumper as Dumper
+    assert Loader and Dumper  # silence pyflakes
 except ImportError:
     from yaml import Loader, Dumper
     logging.info('Using pyyaml for loading and dumping')
@@ -74,7 +77,7 @@ def _load_month_from_disk(path, year_number, month_number):
     except IOError:
         #If that fails, there is nothing to load, so just display an error message
         logging.error('Error: The file %s could not be read' % path)
-    except Exception, err:
+    except Exception:
         logging.error('An error occured while reading %s:' % path)
         raise
     # If we continued here, the possibly corrupted file would be overwritten
@@ -128,4 +131,10 @@ def save_months_to_disk(months, dir, frame, exit_imminent=False, changing_journa
                     frame.show_save_error_dialog(exit_imminent)
                 except IOError:
                     frame.show_save_error_dialog(exit_imminent)
+            try:
+                # Make file readable and writable only by the owner.
+                os.chmod(month_file_string, stat.S_IRUSR | stat.S_IWUSR)
+            except OSError:
+                pass
+
     return something_saved
