@@ -20,11 +20,10 @@
 import signal
 import os
 import re
-from urllib2 import urlopen, URLError
+import httplib
+from urllib2 import urlopen
 import webbrowser
 import logging
-from optparse import IndentedHelpFormatter
-import textwrap
 from distutils.version import StrictVersion
 
 import gtk
@@ -63,13 +62,13 @@ def setup_signal_handlers(journal):
     """
     signals = []
     signal_names = [
-            'SIGHUP',  #Terminal closed, Parent process dead
-            'SIGINT',  #Interrupt from keyboard (CTRL-C)
-            'SIGQUIT', #Quit from keyboard
-            'SIGABRT', #Abort signal from abort(3)
-            'SIGTERM', #Termination signal
-            'SIGTSTP', #Stop typed at tty
-        ]
+        'SIGHUP',   # Terminal closed, Parent process dead
+        'SIGINT',   # Interrupt from keyboard (CTRL-C)
+        'SIGQUIT',  # Quit from keyboard
+        'SIGABRT',  # Abort signal from abort(3)
+        'SIGTERM',  # Termination signal
+        'SIGTSTP',  # Stop typed at tty
+    ]
 
     def signal_handler(signum, frame):
         logging.info('Program was abnormally aborted with signal %s' % signum)
@@ -101,7 +100,7 @@ def get_new_version_number():
         new_version = match.group(1)
         logging.info('%s is the latest version' % new_version)
         return new_version
-    except IOError:
+    except (IOError, httplib.HTTPException):
         return None
 
 
@@ -116,13 +115,16 @@ def check_new_version(journal, current_version, startup=False):
 
     current_version = StrictVersion(current_version)
     # Only compare versions if new version could be read
-    newer_version_available = ((new_version > current_version)
-                    if isinstance(new_version, StrictVersion) else True)
+    newer_version_available = True
+    if isinstance(new_version, StrictVersion):
+        newer_version_available = new_version > current_version
     logging.info('A newer version is available: %s' % newer_version_available)
 
     if newer_version_available or not startup:
         dialog = gtk.MessageDialog(parent=None, flags=gtk.DIALOG_MODAL,
-            type=gtk.MESSAGE_INFO, buttons=gtk.BUTTONS_YES_NO, message_format=None)
+                                   type=gtk.MESSAGE_INFO,
+                                   buttons=gtk.BUTTONS_YES_NO,
+                                   message_format=None)
         dialog.set_transient_for(journal.frame.main_frame)
         primary_text = (_('You have version <b>%s</b>.') % current_version + ' ' +
                         _('The latest version is <b>%s</b>.') % new_version)
@@ -173,74 +175,5 @@ class StreamDuplicator(object):
             stream.flush()
 
     def close(self):
-       for stream in self.streams():
-           self.stream.close()
-
-
-
-class IndentedHelpFormatterWithNL(IndentedHelpFormatter):
-    """
-    Code taken from "Dan"
-    http://groups.google.com/group/comp.lang.python/browse_frm/thread/e72deee779d9989b/
-
-    This class preserves newlines in the optparse help
-    """
-    def format_description(self, description):
-        if not description: return ""
-        desc_width = self.width - self.current_indent
-        indent = " "*self.current_indent
-        # the above is still the same
-        bits = description.split('\n')
-        formatted_bits = [
-            textwrap.fill(bit,
-                desc_width,
-                initial_indent=indent,
-                subsequent_indent=indent)
-            for bit in bits]
-        result = "\n".join(formatted_bits) + "\n"
-        return result
-
-    def format_option(self, option):
-        # The help for each option consists of two parts:
-        #    * the opt strings and metavars
-        #    eg. ("-x", or "-f FILENAME, --file=FILENAME")
-        #    * the user-supplied help string
-        #    eg. ("turn on expert mode", "read data from FILENAME")
-        #
-        # If possible, we write both of these on the same line:
-        #    -x     turn on expert mode
-        #
-        # But if the opt string list is too long, we put the help
-        # string on a second line, indented to the same column it would
-        # start in if it fit on the first line.
-        #    -f FILENAME, --file=FILENAME
-        #            read data from FILENAME
-        result = []
-        opts = self.option_strings[option]
-        opt_width = self.help_position - self.current_indent - 2
-        if len(opts) > opt_width:
-            opts = "%*s%s\n" % (self.current_indent, "", opts)
-            indent_first = self.help_position
-        else: # start help on same line as opts
-            opts = "%*s%-*s " % (self.current_indent, "", opt_width, opts)
-            indent_first = 0
-        result.append(opts)
-        if option.help:
-            help_text = option.help
-            # Everything is the same up through here
-            help_lines = []
-            help_text = "\n".join([x.strip() for x in
-                                help_text.split("\n")])
-            for para in help_text.split("\n\n"):
-                help_lines.extend(textwrap.wrap(para, self.help_width))
-                if len(help_lines):
-                    # for each paragraph, keep the double newlines..
-                    help_lines[-1] += "\n"
-                    # Everything is the same after here
-            result.append("%*s%s\n" % (
-                indent_first, "", help_lines[0]))
-            result.extend(["%*s%s\n" % (self.help_position, "", line)
-                for line in help_lines[1:]])
-        elif opts[-1] != "\n":
-            result.append("\n")
-        return "".join(result)
+        for stream in self.streams():
+            self.stream.close()
